<?php
/**
 * WooCommerce Price Robot
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Price_Robot' ) ) :

class Alg_WC_Price_Robot {

	/**
	 * Constructor
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function __construct() {
		if ( 'yes' === get_option( 'alg_price_robot_general_auto_pricing_enabled', 'yes' ) ) {
			$this->is_wc_version_below_3 = version_compare( get_option( 'woocommerce_version', null ), '3.0.0', '<' );
			$sale_price_filter  = ( $this->is_wc_version_below_3 ) ? 'woocommerce_get_sale_price' : 'woocommerce_product_get_sale_price';
			$this->price_filter = ( $this->is_wc_version_below_3 ) ? 'woocommerce_get_price'      : 'woocommerce_product_get_price';
			// Price filter
			add_filter( $this->price_filter, 'alg_price_robot', PHP_INT_MAX, 2 );
			// Price filter - variations
			add_filter( 'woocommerce_variation_prices_price', 'alg_price_robot', PHP_INT_MAX, 2 );
			add_filter( 'woocommerce_get_variation_prices_hash', array( $this, 'get_variation_prices_hash' ), PHP_INT_MAX, 3 );
			if ( ! $this->is_wc_version_below_3 ) {
				add_filter( 'woocommerce_product_variation_get_price', 'alg_price_robot', PHP_INT_MAX, 2 );
			}
			if ( 'yes' === get_option( 'alg_price_robot_general_display_as_sale', 'yes' ) ) {
				// Sale price filters
				add_filter( $sale_price_filter, 'alg_price_robot', PHP_INT_MAX, 2 );
				add_filter( 'woocommerce_product_is_on_sale', array( $this, 'price_robot_on_sale' ), PHP_INT_MAX, 2 );
				// Sale price filters - variations
				add_filter( 'woocommerce_variation_prices_sale_price', 'alg_price_robot', PHP_INT_MAX, 2 );
				if ( ! $this->is_wc_version_below_3 ) {
					add_filter( 'woocommerce_product_variation_get_sale_price', 'alg_price_robot', PHP_INT_MAX, 2 );
				}
			}
		}
	}

	/**
	 * get_variation_prices_hash.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function get_variation_prices_hash( $price_hash, $_product, $display ) {
		$product_id = alg_price_robot_get_product_or_variation_parent_id( $_product, $this->is_wc_version_below_3 );
		$price_hash['alg_price_robot_price_hash']['products'][ $product_id ]['enabled']   = get_post_meta( $product_id, '_price_robot_enabled', true );
		$price_hash['alg_price_robot_price_hash']['general']['display_as_sale']           = get_option( 'alg_price_robot_general_display_as_sale', 'yes' );
		$price_hash['alg_price_robot_price_hash']['general']['variable_as_single']        = get_option( 'alg_price_robot_general_variable_as_single', 'no' );
		$price_hash['alg_price_robot_price_hash']['last_sale']['discount_timeframe_days'] = get_option( 'alg_price_robot_last_sale_discount_timeframe_days', 30 );
		$price_hash['alg_price_robot_price_hash']['last_sale']['discount_step_percent']   = get_option( 'alg_price_robot_last_sale_discount_step_percent', 5 );
		$price_hash['alg_price_robot_price_hash']['last_sale']['discount_max_percent']    = get_option( 'alg_price_robot_last_sale_discount_max_percent', 25 );
		$price_hash['alg_price_robot_price_hash']['last_sale']['min_stock']               = get_option( 'alg_price_robot_last_sale_min_stock', 0 );
		$price_hash['alg_price_robot_price_hash']['last_sale']['goal_sale_rate']          = get_option( 'alg_price_robot_last_sale_goal_sale_rate', 0 );
		$price_hash['alg_price_robot_price_hash']['pretty_price']['round_type']           = get_option( 'alg_price_robot_pretty_price_round_type', 'ceil' );
		$price_hash['alg_price_robot_price_hash']['pretty_price']['max_price']            = get_option( 'alg_price_robot_pretty_price_max_price', 0 );
		$price_hash['alg_price_robot_price_hash']['orders_cron']['started']               = get_option( 'get_orders_cron_started', 0 );
		return $price_hash;
	}

	/**
	 * price_robot
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function price_robot_on_sale( $is_on_sale, $_product ) {
		$product_id = alg_price_robot_get_product_or_variation_parent_id( $_product, $this->is_wc_version_below_3 );
		if ( 'yes' === get_post_meta( $product_id, '_price_robot_enabled', true ) ) {
			// Get original price
			remove_filter( $this->price_filter, 'alg_price_robot', PHP_INT_MAX, 2 );
			$original_price = $_product->get_price();
			add_filter(    $this->price_filter, 'alg_price_robot', PHP_INT_MAX, 2 );
			// Get robot(s) price
			$robot_price = alg_price_robot( $original_price, $_product, true );
			// Decide if on sale
			return ( $robot_price < $original_price ) ? true : $is_on_sale;
		}
		return $is_on_sale;
	}
}

endif;

return new Alg_WC_Price_Robot();
