<?php
/**
 * WooCommerce Price Robot - Functions
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! function_exists( 'alg_price_robot_get_product_or_variation_id' ) ) {
	/**
	 * alg_price_robot_get_product_or_variation_id.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function alg_price_robot_get_product_or_variation_id( $_product, $is_wc_version_below_3 ) {
		return ( $is_wc_version_below_3 ? ( isset( $_product->variation_id ) ? $_product->variation_id : $_product->id ) : $_product->get_id() );
	}
}

if ( ! function_exists( 'alg_price_robot_get_product_or_variation_parent_id' ) ) {
	/**
	 * alg_price_robot_get_product_or_variation_parent_id.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function alg_price_robot_get_product_or_variation_parent_id( $_product, $is_wc_version_below_3 ) {
		return ( $is_wc_version_below_3 ? $_product->id : ( $_product->is_type( 'variation' ) ? $_product->get_parent_id() : $_product->get_id() ) );
	}
}

if ( ! function_exists( 'alg_price_robot_get_product_id' ) ) {
	/**
	 * alg_price_robot_get_product_id.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function alg_price_robot_get_product_id( $_product, $is_wc_version_below_3 ) {
		return ( 'no' === get_option( 'alg_price_robot_general_variable_as_single', 'no' ) ?
			alg_price_robot_get_product_or_variation_id(        $_product, $is_wc_version_below_3 ) :
			alg_price_robot_get_product_or_variation_parent_id( $_product, $is_wc_version_below_3 )
		);
	}
}

if ( ! function_exists( 'alg_get_cron_update_intervals' ) ) {
	/**
	 * alg_get_cron_update_intervals.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function alg_get_cron_update_intervals() {
		return array(
			'minutely'   => __( 'Update Every Minute', 'price-robot-for-woocommerce' ),
			'hourly'     => __( 'Update Hourly', 'price-robot-for-woocommerce' ),
			'twicedaily' => __( 'Update Twice Daily', 'price-robot-for-woocommerce' ),
			'daily'      => __( 'Update Daily', 'price-robot-for-woocommerce' ),
			'weekly'     => __( 'Update Weekly', 'price-robot-for-woocommerce' ),
		);
	}
}

if ( ! function_exists( 'alg_wc_price_robot_get_data_last_updated_message' ) ) {
	/**
	 * alg_wc_price_robot_get_data_last_updated_message.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function alg_wc_price_robot_get_data_last_updated_message() {
		$cron_finished_time = get_option( 'get_orders_cron_finished', 0 );
		return ( 0 != $cron_finished_time ? sprintf( __( 'Data last updated on %s.', 'price-robot-for-woocommerce' ), date( 'Y-m-d H:i:s', $cron_finished_time ) ) : '' );
	}
}

if ( ! function_exists( 'alg_is_frontend' ) ) {
	/**
	 * alg_is_frontend.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function alg_is_frontend() {
		return ( ! is_admin() || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) );
	}
}

if ( ! function_exists( 'alg_price_robot' ) ) {
	/**
	 * alg_price_robot.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function alg_price_robot( $price, $_product, $advisor_mode = false ) {

		$is_wc_version_below_3 = version_compare( get_option( 'woocommerce_version', null ), '3.0.0', '<' );
		$_product_id           = alg_price_robot_get_product_id( $_product, $is_wc_version_below_3 );
		$_parent_product_id    = alg_price_robot_get_product_or_variation_parent_id( $_product, $is_wc_version_below_3 );

		if ( $advisor_mode || 'yes' === get_post_meta( $_parent_product_id, '_price_robot_enabled', true ) ) {
			$original_price = $price;
			$modified_price = apply_filters( 'alg_woocommerce_price_robot', $price, $_product_id, $original_price );
			$price          = ( $modified_price > 0 ) ? round( $modified_price, get_option( 'woocommerce_price_num_decimals', 2 ) ) : 0;
			$price          = ( abs( $price - $original_price ) < 1 ) ? $original_price : $price;
		}

		return $price;
	}
}
