<?php
/**
 * WooCommerce Price Robot - Pretty Price Robot
 *
 * @version 1.0.1
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Price_Robot_Pretty_Price' ) ) :

class Alg_WC_Price_Robot_Pretty_Price extends Alg_WC_Price_Robot_Abstract {

	/**
	 * Constructor.
	 *
	 * @version 1.0.1
	 * @since   1.0.0
	 */
	function __construct() {

		$this->id       = 'pretty_price';
		$this->title    = __( 'Final Price', 'price-robot-for-woocommerce' );
		$this->desc     = __( 'When enabled, modifies the product price, so that it <strong>includes 99 cents</strong> in it. E.g. if current price is $98.55, robot will change it to $98.99.', 'price-robot-for-woocommerce' ) . '<br>' .
			__( 'The robot changes the product price last, after all other robots made their modifications to the price. This insures that <strong>price is final</strong> and no other changes are made afterwards.', 'price-robot-for-woocommerce' ) . '<br>' .
			__( 'Applied to all products with <strong>price robot enabled</strong> option.', 'price-robot-for-woocommerce' );
		$this->priority = 100;

		parent::__construct();
	}

	/**
	 * get_price.
	 *
	 * @version 1.0.1
	 * @since   1.0.0
	 */
	function get_price( $price, $product_id, $original_price ) {
		$rounding_function = get_option( 'alg_price_robot_pretty_price_round_type', 'ceil' );
		$price             = $rounding_function( $price );
		$max_price         = get_option( 'alg_price_robot_pretty_price_max_price', 0 );
		if ( $price > 0 && ( 0 == $max_price || $price <= $max_price ) ) {
			$price = $price - 0.01;
		}
		return $price;
	}

	/**
	 * get_settings.
	 *
	 * @version 1.0.1
	 * @since   1.0.0
	 */
	function get_settings() {
		$settings = array(
			array(
				'title'     => __( 'Robot Options', 'price-robot-for-woocommerce' ),
				'type'      => 'title',
				'id'        => 'alg_price_robot_pretty_price_options',
			),
			array(
				'title'     => __( 'Rounding Type', 'price-robot-for-woocommerce' ),
				'desc_tip'  => __( 'Select how to round the price before setting 99 cents.', 'price-robot-for-woocommerce' ),
				'id'        => 'alg_price_robot_pretty_price_round_type',
				'default'   => 'ceil',
				'type'      => 'select',
				'options'   => array(
					'round' => __( 'Round', 'price-robot-for-woocommerce' ),
					'ceil'  => __( 'Round Up', 'price-robot-for-woocommerce' ),
					'floor' => __( 'Round Down', 'price-robot-for-woocommerce' ),
				),
			),
			array(
				'title'     => __( 'Maximum Price', 'price-robot-for-woocommerce' ),
				'desc_tip'  => __( 'Maximum price. Set zero to disable and apply robot to any price.', 'price-robot-for-woocommerce' ),
				'id'        => 'alg_price_robot_pretty_price_max_price',
				'default'   => 0,
				'type'      => 'number',
				'custom_attributes' => array( 'step' => '0.0001', 'min'  => '0' ),
			),
			array(
				'type'      => 'sectionend',
				'id'        => 'alg_price_robot_pretty_price_options',
			),
		);
		return array_merge( parent::get_settings(), $settings );
	}

}

endif;

return new Alg_WC_Price_Robot_Pretty_Price();
